Configurations
==============

Pydantic models documentation for application configurations.

**Content**

* `Main`_
* `I/O`_
* `Solver`_
* `Posfilter`_
* `Transponders`_

Main
----
.. automodule:: gnatss.configs.main
   :members:

I/O
----

.. automodule:: gnatss.configs.io
   :members:

Solver
------

.. automodule:: gnatss.configs.solver
   :members:

Posfilter
---------

.. automodule:: gnatss.configs.posfilter
   :members:

Transponders
------------

.. automodule:: gnatss.configs.transponders
   :members:
